@@ -13,7 +13,7 @@ use t::lib::Custom ();
 use t::lib::MyClass ();
 use t::lib::MyHtmlWindow ();
 
-our $VERSION = '0.75';
+our $VERSION = '0.76';
 our @ISA     = 'Wx::Dialog';
 
 sub new {
@@ -117,6 +117,14 @@ sub new {
 		Wx::gettext("Toggle something")
 	);
 
+	Wx::Event::EVT_TOGGLEBUTTON(
+		$self,
+		$self->{m_toggleBtn1},
+		sub {
+			shift->toggle_me(@_);
+		},
+	);
+
 	$self->{m_bpButton1} = Wx::BitmapButton->new(
 		$self,
 		-1,
@@ -946,6 +954,10 @@ sub m_button1 {
 	warn 'Handler method m_button1 for event m_button1.OnButtonClick not implemented';
 }
 
+sub toggle_me {
+	warn 'Handler method toggle_me for event m_toggleBtn1.OnToggleButton not implemented';
+}
+
 sub list_col_click {
 	warn 'Handler method list_col_click for event m_listCtrl1.OnListColClick not implemented';
 }
